@@ -25,7 +25,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <gtk/gtksignal.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include "gtkhtml.h"
 #include "gtkhtml-embedded.h"
 #include "htmlembedded.h"
@@ -93,7 +93,7 @@ draw (HTMLObject *o,
 		}
 	}
 
-	d (printf ("draw embedded %p - call painter\n", element));
+	d (printf ("draw embedded %p - call painter tx %d ty %d\n", element, tx, ty));
 	html_painter_draw_embedded (p, element, tx, ty);
 }
 
@@ -161,7 +161,7 @@ html_embedded_real_calc_size (HTMLObject *self, HTMLPainter *painter, GList **ch
 	GtkWidget *widget;
 	HTMLEmbedded *emb = HTML_EMBEDDED (self);
 	gint pixel_size;
-	gint old_width, old_ascent, old_descent;
+	gint old_width, old_ascent;
 	GtkRequisition requisition;
 
 	widget = emb->widget;
@@ -172,7 +172,6 @@ html_embedded_real_calc_size (HTMLObject *self, HTMLPainter *painter, GList **ch
 
 	old_width = self->width;
 	old_ascent = self->ascent;
-	old_descent = self->descent;
 
 	requisition.width = requisition.height = 0;
 	gtk_widget_size_request (widget, &requisition);
